cont

package module
v0.0.0-...-c693971 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 22, 2020 License: MIT Imports: 2 Imported by: 0

README

移行しました

go-utils/cont

これはなんぞ?

"Hello, World!" の中に"Hello"が含まれているか知りたい場合は string.Contains("Hello, World!", "Hello") で良い
[]string{"1", "2", "3"}の中に"1"が含まれているか知りたい時は自前実装しないといけない
そんな時に一つにまとめられていて少しでも使えるものを作りました。

contとは

Easy Contains

導入

go get -u github.com/54m/cont

Example

ライセンス

MIT

Documentation

Overview

Package cont - Checks if the target is contained in a string, slice or map

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Contains

func Contains(target, obj interface{}) bool

Contains returns true if there is something in the target supports type: string, slice, array, map

Types

This section is empty.

Directories

Path Synopsis

Jump to