package
module
Version:
v0.0.0-...-c693971
Opens a new window with list of versions in this module.
Published: May 22, 2020
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
移行しました
→ go-utils/cont
これはなんぞ?
"Hello, World!" の中に"Hello"が含まれているか知りたい場合は string.Contains("Hello, World!", "Hello") で良い
[]string{"1", "2", "3"}の中に"1"が含まれているか知りたい時は自前実装しないといけない
そんな時に一つにまとめられていて少しでも使えるものを作りました。
contとは
Easy Contains
導入
go get -u github.com/54m/cont
Example
ライセンス
MIT
Documentation
¶
Package cont - Checks if the target is contained in a string, slice or map
func Contains(target, obj interface{}) bool
Contains returns true if there is something in the target
supports type: string, slice, array, map
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.